local api = require("gemini.api")
local M = {}

-- Cache for completion items
local completion_cache = {}

-- Helper function to create completion items from Gemini response
local function parse_completion_response(response)
    -- Split response into lines and filter out empty ones
    local lines = vim.split(response, "\n")
    local items = {}
    
    for _, line in ipairs(lines) do
        if line and line:match("^%s*[^%s]") then -- Skip empty lines
            table.insert(items, {
                label = line,
                kind = vim.lsp.protocol.CompletionItemKind.Text,
                detail = "Gemini suggestion",
                documentation = {
                    kind = "markdown",
                    value = "```\n" .. line .. "\n```"
                }
            })
        end
    end
    
    return items
end

function M.get_completion(params, callback)
    local cursor = vim.api.nvim_win_get_cursor(0)
    local line = cursor[1]
    local col = cursor[2]
    
    -- Get current buffer content for context
    local lines = vim.api.nvim_buf_get_lines(0, math.max(0, line - 10), line, false)
    local prefix = table.concat(lines, "\n")
    
    -- Get current line up to cursor
    local current_line = vim.api.nvim_get_current_line()
    local before_cursor = string.sub(current_line, 1, col)
    
    -- Construct prompt for Gemini
    local prompt = string.format(
        "Complete this code. Only provide the completion, no explanation:\n%s\n%s",
        prefix,
        before_cursor
    )
    
    -- Check cache first
    local cache_key = prefix .. before_cursor
    if completion_cache[cache_key] then
        callback(completion_cache[cache_key])
        return
    end
    
    -- Get completion from Gemini
    api.get_response(prompt, nil, function(response, error)
        if error then
            vim.notify("Completion error: " .. error, vim.log.levels.ERROR)
            callback({})
            return
        end
        
        local items = parse_completion_response(response)
        completion_cache[cache_key] = items
        callback(items)
    end)
end

return M